..  Copyright 2012 ShopWiki
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at
       http://www.apache.org/licenses/LICENSE-2.0
    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

.. Clortho documentation master file, created by
   sphinx-quickstart on Mon Dec  3 11:32:23 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Clortho's documentation!
================================

Contents:

.. toctree::
    auth


Quick Start
================================
.. literalinclude:: ../clortho/tests/example.py
    :lines: 20-
    :linenos:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

